## Set working directory

setwd("C:/Users/Adrian Ryan/Documents/Parapsychology/Greg K/Data/Processed data")

## Read raw data and cast to appropriate format

data <- read.csv("GregsARVdata2-dates-fixed.csv", as.is=TRUE)

data$RV.DateTime.MST <- strptime(paste(data$RV.Date.MST, data$RV.Time.MST, sep=" "),
                                 format='%d/%m/%Y %H:%M:%S')
data$Feedback.DateTime.MST <- strptime(paste(data$Feedback.Date.MST, data$Feedback.Time.MST, sep=" "),
                                 format='%d/%m/%Y %H:%M:%S')

data$RV.Date.MST <- as.Date(data$RV.Date.MST,format='%d/%m/%Y')
data$Feedback.Date.MST <- as.Date(data$Feedback.Date.MST,format='%d/%m/%Y')

data$RV.DateTime.MST <- as.POSIXct(data$RV.DateTime.MST)
data$Feedback.DateTime.MST <- as.POSIXct(data$Feedback.DateTime.MST)

data$Conf.Score <- as.factor(data$Conf.Score)
data$Right.Wrong <- as.integer(data$Right.Wrong)

data$Right.Wrong[data$Right.Wrong == -1] <- as.integer(0)

# Sort.. not actually necessary
library("plyr")
data <- arrange(data, RV.DateTime.MST)

# Add Session and Trial columns

df <- data.frame(matrix(NA, nrow = nrow(data), ncol = 2))
names(df) <- c("Session", "Trial") 

Trial <- as.integer(1) # Trial in session
Session <- as.integer(1) # Session number 
RV.DateTime.MST.Last <- data[1, "RV.DateTime.MST"]
for(row in seq_len(nrow(data))) {
  if (as.numeric(data[row, "RV.DateTime.MST"] - RV.DateTime.MST.Last, units = "mins") > 30) {
    Session <- Session + 1
    Trial <- as.integer(1)
  }
  df[row, 1] <- Session
  df[row, 2] <- Trial
  Trial <- Trial + 1
  RV.DateTime.MST.Last <- data[row, "RV.DateTime.MST"]
}
data <- cbind(data, df)

Smeans <- ddply(data, .(Session), summarise, 
            RV.DateTime.MST.Min = min(RV.DateTime.MST),
            First.Feedback.DateTime.MST = min(Feedback.DateTime.MST),
            Last.Feedback.DateTime.MST = max(Feedback.DateTime.MST),
            Feedback.Period.Mins = round(as.numeric(Last.Feedback.DateTime.MST - First.Feedback.DateTime.MST, units = "mins")),
            Precog.Mins = round(as.numeric(First.Feedback.DateTime.MST - RV.DateTime.MST.Min, units = "mins")),
            First.Feedback.Date.MST = min(Feedback.Date.MST),
            Last.Feedback.Date.MST = max(Feedback.Date.MST),
            Feedback.Period.Days = round(as.numeric(Last.Feedback.Date.MST - First.Feedback.Date.MST, units = "days")),
            RV.Date.MST.Min = min(RV.Date.MST),
            Precog.Days = round(as.numeric(First.Feedback.Date.MST - RV.Date.MST.Min, units = "days")),
            N = length(Right.Wrong), 
            hits = sum(Right.Wrong),
            p.hits = pbinom(hits-1, size=N, prob=0.5, lower.tail=FALSE),
            p.misses = pbinom(hits, size=N, prob=0.5),
            z.hits = qnorm(p.hits, lower.tail = FALSE),
            z.misses = qnorm(p.misses, lower.tail = FALSE) * -1,
            z.single = ifelse(N == 1, ifelse(hits == 1, 1, -1), NA),
            z.multi = round(ifelse(hits == N/2, 0, ifelse(hits > N/2, z.hits, z.misses)), digits = 3),
            z = ifelse(N == 1, z.single, z.multi),
            RV.SWS = mean(RV.SWS))

drops <- c("RV.Date.MST.Min","p.hits", "p.misses", "z.hits", "z.misses", "z.single", "z.multi")
Smeans <- Smeans[,!(names(Smeans) %in% drops)]

write.csv(Smeans, "SessionData.csv", row.names = FALSE)

# the probability of getting 4 or fewer trials correct, out of 12
pbinom(4, size=12, prob=0.5)
#therefore the probability of getting 5 or more right is 1 - this
1 - pbinom(4, size=12, prob=0.5)
#which is the same as
pbinom(4, size=12, prob=0.5, lower.tail=FALSE)
